@@ -1,4 +1,4 @@
-# Copyright (c) 2010 gocept gmbh & co. kg
+# Copyright (c) 2011 gocept gmbh & co. kg
 # See also LICENSE.txt
 
 import cStringIO
@@ -43,15 +43,15 @@ class Controller(object):
     def prepare(self):
         """Prepare ancillary objects: option parser and logger."""
         self.optparser = nagiosplugin.pluginoptparse.PluginOptionParser()
-        self.optparser.add_option(u'-V', u'--version', action='version',
+        self.optparser.add_option('-V', '--version', action='version',
                 help=u'print version and exit')
-        self.optparser.add_option(u'-v', u'--verbose', action='count',
+        self.optparser.add_option('-v', '--verbose', action='count',
                 default=0, help=u'increase output verbosity (up to 3 times)')
-        self.optparser.add_option(u'-t', u'--timeout', metavar=u'TIMEOUT',
+        self.optparser.add_option('-t', '--timeout', metavar='TIMEOUT',
                 default=15, type='int',
-                help=(u'abort execution after TIMEOUT seconds '
-                      u'(default: %default)'))
-        self.logger = logging.getLogger(u'nagiosplugin')
+                help=u'abort execution after TIMEOUT seconds '
+                     u'(default: %default)')
+        self.logger = logging.getLogger('nagiosplugin')
         self.logger.setLevel(logging.DEBUG)
         self.logstream = cStringIO.StringIO()
         handler = logging.StreamHandler(self.logstream)
@@ -77,12 +77,14 @@ class Controller(object):
         except TimeoutError:
             self.states.append(nagiosplugin.state.Unknown(
                 u'timeout of %is exceeded' % self.opts.timeout))
-        except Exception as e:
+        except Exception:
+            e = sys.exc_info()[1]
             self.states.append(nagiosplugin.state.Unknown(str(e)))
             if self.opts.verbose > 0:
                 self.stderr += traceback.format_exc()
         try:
-            self.dominant_state = reduce(nagiosplugin.state.reduce, self.states)
+            self.dominant_state = reduce(
+                nagiosplugin.state.reduce, self.states)
         except TypeError:
             pass
         self.exitcode = self.dominant_state.code
@@ -117,7 +119,7 @@ class Controller(object):
         return out
 
     def firstline(self):
-        """Return check status and performance data (not more than 80 chars)."""
+        """Return check status and performance data."""
         out = u'%s %s' % (self.check.shortname, str(self.dominant_state))
         if self.dominant_state.headline():
             out += u' - ' + self.dominant_state.headline()
